@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # Orca
 #
-# Copyright 2004-2006 Sun Microsystems Inc.
+# Copyright 2004-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -15,16 +15,16 @@
 #
 # You should have received a copy of the GNU Library General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 
 """Provides getCharacterName that maps punctuation marks and other
 individual characters into localized words."""
 
-__id__        = "$Id: chnames.py 3266 2007-11-29 00:48:02Z wwalker $"
-__version__   = "$Revision: 3266 $"
-__date__      = "$Date: 2007-11-28 19:48:02 -0500 (Wed, 28 Nov 2007) $"
-__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__id__        = "$Id: chnames.py 3882 2008-05-07 18:22:10Z richb $"
+__version__   = "$Revision: 3882 $"
+__date__      = "$Date: 2008-05-07 14:22:10 -0400 (Wed, 07 May 2008) $"
+__copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 from orca_i18n import _ # for gettext support
